@@ -1,3 +1,5 @@
+import os
+os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = 'hide'
 import pygame as pg
 import pymunk as pm
 from pymunk import Vec2d
@@ -531,7 +533,7 @@ class raw_env(AECEnv, EzPickle):
             f = Fence(w_type, s_pos, b_pos, verts, self.space)
             self.fences.append(f)
 
-        self.metadata = {"render.modes": ["human", "rgb_array"]}
+        self.metadata = {"render.modes": ["human", "rgb_array"], 'name': "prospector_v3"}
 
         self.action_spaces = {}
         for p in self.prospectors:
