@@ -17,7 +17,7 @@ def env():
 
 
 class raw_env(AECEnv):
-    metadata = {'render.modes': ['human']}
+    metadata = {'render.modes': ['human'], "name": "connect_four_v2"}
 
     def __init__(self):
         super().__init__()
